#
# spec file for package python-beautifulsoup
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-beautifulsoup
Version:        3.2.1
Release:        lp151.2.1
Summary:        HTML/XML Parser for Quick-Turnaround Applications Like Screen-Scraping
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://www.crummy.com/software/BeautifulSoup/
Source:         https://pypi.python.org/packages/source/B/BeautifulSoup/BeautifulSoup-%{version}.tar.gz
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Beautiful Soup is a Python HTML/XML parser designed for quick turnaround
projects like screen-scraping. Three features make it powerful:

* Beautiful Soup won't choke if you give it bad markup. It yields a parse tree
  that makes approximately as much sense as your original document. This is
  usually good enough to collect the data you need and run away

* Beautiful Soup provides a few simple methods and Pythonic idioms for
  navigating, searching, and modifying a parse tree: a toolkit for dissecting a
  document and extracting what you need. You don't have to create a custom
  parser for each application

* Beautiful Soup automatically converts incoming documents to Unicode and
  outgoing documents to UTF-8. You don't have to think about encodings, unless
  the document doesn't specify an encoding and Beautiful Soup can't autodetect
  one. Then you just have to specify the original encoding

Beautiful Soup parses anything you give it, and does the tree traversal stuff
for you. You can tell it "Find all the links", or "Find all the links of class
externalLink", or "Find all the links whose urls match "foo.com", or "Find the
table heading that's got bold text, then give me that text."

Valuable data that was once locked up in poorly-designed websites is now within
your reach. Projects that would have taken hours take only minutes with
Beautiful Soup.

%prep
%setup -q -n BeautifulSoup-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python BeautifulSoupTests.py

%files
%defattr(-,root,root)
%{python_sitelib}/BeautifulSoup-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/BeautifulSoup*

%changelog
* Mon Jul 15 2013 speilicke@suse.com
- Use upstream URL
- Run testsuite
* Mon Feb 11 2013 saschpe@suse.de
- Spec file cleanup, should fix 12.1 build
* Tue Feb 21 2012 jfunk@funktronics.ca
- Update to 3.2.1
  * Substitute XML entities for angle brackets and bare ampersands within
    strings, not just within attribute values. This prevents a possible
    cross-site scripting attack when Beautiful Soup is used to sanitize HTML.
    (https://bugs.launchpad.net/beautifulsoup/+bug/868921)
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Nov 25 2011 jfunk@funktronics.ca
- Update to 3.2.0
  - Gave the stable series a higher version number than the unstable series,
    to make it very clear which series most people should be using.
  - When creating a Tag object, you can specify its attributes as a dict
    rather than as a list of 2-tuples.
* Tue Jul  6 2010 coolo@novell.com
- fix dates in changelog
* Sat Apr 10 2010 alexandre@exatati.com.br
- Update to 3.0.8.1;
- Spec file cleaned with spec-cleaner.
* Fri Jan  8 2010 alexandre@exatati.com.br
- Update to 3.0.8;
- Building as noarch for openSUSE >= 11.2.
* Tue Dec  9 2008 cfarrell1980@gmail.com
- Update to 3.0.7a
  - Release 3.0.7a (2008/07/03)
  - Added an import that makes BS work in Python 2.3.
  - Release 3.0.7 (2008/06/22)
  - Fixed a UnicodeDecodeError when unpickling documents that contain non-ASCII characters.
  - Fixed a TypeError that occured in some circumstances when a tag contained no text.
  - Jump through hoops to avoid the use of chardet, which can be slow in some circumstances. UTF-8 documents should never trigger the use of chardet.
  - Whitespace is preserved inside <pre> and <textarea> tags that contain nothing but whitespace.
  - Beautiful Soup can now parse a doctype that's scoped to an XML namespace.
- Update to 3.0.6
  - Release 3.0.6 (2008/04/26)
  - Added a Tag.decompose() method to disconnect a tree or subset, breaking it into bite-sized pieces for the garbage collecter to collect.
  - Got rid of a very old debug line that prevented chardet from working.
  - Tag.extract() now returns the tag that was extracted.
  - Tag.findNext() now does something with the keyword arguments you pass it instead of dropping them on the floor.
  - Fixed a Unicode conversion bug.
  - Fixed a bug that garbled some tags when rewriting them.
* Tue Dec 18 2007 jfunk@funktronics.ca
- Update to 3.0.5:
  - Beautiful Soup is now licensed under a BSD-style license
  - Soup objects can now be pickled, and copied with copy.deepcopy
  - Tag.append now works properly on existing BS objects. (It wasn't originally
    intended for outside use, but it can be now.) (Giles Radford)
  - Passing in a nonexistent encoding will no longer crash the parser on Python
    2.4 (John Nagle)
  - Fixed an underlying bug in SGMLParser that thinks ASCII has 255 characters
    instead of 127 (John Nagle)
  - Entities are converted more consistently to Unicode characters
  - Entity references in attribute values are now converted to Unicode
    characters when appropriate. Numeric entities are always converted, because
    SGMLParser always converts them outside of attribute values
  - ALL_ENTITIES happens to just be the XHTML entities, so I renamed it to
    XHTML_ENTITIES
  - The regular expression for bare ampersands was too loose. In some cases
    ampersands were not being escaped. (Sam Ruby?)
  - Non-breaking spaces and other special Unicode space characters are no
    longer folded to ASCII spaces. (Robert Leftwich)
  - Information inside a TEXTAREA tag is now parsed literally, not as HTML
    tags. TEXTAREA now works exactly the same way as SCRIPT. (Zephyr Fang)
* Mon Apr 23 2007 jfunk@funktronics.ca
- Update to 3.0.4:
  - Fixed a bug that crashed Unicode conversion in some cases
  - Fixed a bug that prevented UnicodeDammit from being used as a general-
    purpose data scrubber
  - Fixed some unit test failures when running against Python 2.5
  - When considering whether to convert smart quotes, UnicodeDammit now looks
    at the original encoding in a case-insensitive way
* Wed Aug 30 2006 jfunk@funktronics.ca
- Initial release
